"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RotateWidget = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("../..");
const hooks_1 = require("../../hooks");
const RotateWidget = (props) => {
    const viewerState = hooks_1.useViewerState();
    const previewImages = hooks_1.usePreviewImages();
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const rotateFunc = (newRotation, direction, pageIndex) => {
        const existingObj = newRotation.find((rotation) => rotation.pageNum === pageIndex);
        if (newRotation.length > 0 && existingObj) {
            const prevValue = existingObj.degree || 0;
            existingObj.degree = __1.ImageUtil.normalizeDegrees((prevValue + ((direction === 'left' ? -__1.ROTATION_AMOUNT : __1.ROTATION_AMOUNT) % 360)) % 360);
        }
        else {
            newRotation.push({
                pageNum: pageIndex,
                degree: __1.ImageUtil.normalizeDegrees((0 + ((direction === 'left' ? -__1.ROTATION_AMOUNT : __1.ROTATION_AMOUNT) % 360)) % 360),
            });
        }
    };
    const rotateDocument = react_1.useCallback((direction) => {
        var _a;
        const newRotation = (_a = viewerState.rotation) !== null && _a !== void 0 ? _a : [];
        if (props.pages === 'all') {
            previewImages.imageData.forEach((page) => {
                rotateFunc(newRotation, direction, page.Index);
            });
        }
        else {
            rotateFunc(newRotation, direction, viewerState.activePage);
        }
        viewerState.updateState({
            rotation: newRotation,
        });
        //update shapes as well
        const newImages = previewImages.imageData.map((img) => {
            updateDocumentData({
                shapes: {
                    annotations: __1.applyShapeRotations(documentData.shapes.annotations, direction === 'left' ? -__1.ROTATION_AMOUNT : __1.ROTATION_AMOUNT, img),
                    highlights: __1.applyShapeRotations(documentData.shapes.highlights, direction === 'left' ? -__1.ROTATION_AMOUNT : __1.ROTATION_AMOUNT, img),
                    redactions: __1.applyShapeRotations(documentData.shapes.redactions, direction === 'left' ? -__1.ROTATION_AMOUNT : __1.ROTATION_AMOUNT, img),
                },
            });
            return img;
        });
        previewImages.setImageData(newImages);
    }, [
        documentData.shapes.annotations,
        documentData.shapes.highlights,
        documentData.shapes.redactions,
        previewImages,
        props.pages,
        updateDocumentData,
        viewerState,
    ]);
    switch (props.mode) {
        case __1.ROTATION_MODE.anticlockwise:
        case __1.ROTATION_MODE.clockwise:
            return props.renderButton(props.mode, rotateDocument);
        default:
            return (react_1.default.createElement("div", { style: { display: 'inline-block' } },
                props.renderButton(__1.ROTATION_MODE.anticlockwise, rotateDocument),
                props.renderButton(__1.ROTATION_MODE.clockwise, rotateDocument)));
    }
};
exports.RotateWidget = RotateWidget;
//# sourceMappingURL=rotate-widget.js.map