"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Page = void 0;
const tslib_1 = require("tslib");
const CircularProgress_1 = tslib_1.__importDefault(require("@material-ui/core/CircularProgress"));
const Paper_1 = tslib_1.__importDefault(require("@material-ui/core/Paper"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
const services_1 = require("../services");
const document_viewer_layout_1 = require("./document-viewer-layout");
const shapes_1 = require("./shapes");
const Page = (props) => {
    var _a, _b, _c;
    const viewerState = hooks_1.useViewerState();
    const page = hooks_1.usePreviewImage(props.page.Index);
    const commentState = hooks_1.useCommentState();
    const isActive = page.image && viewerState.activePage === page.image.Index;
    const imgUrl = (page.image && ((_a = page.image) === null || _a === void 0 ? void 0 : _a.PreviewImageUrl)) || '';
    const imageRotation = services_1.ImageUtil.normalizeDegrees(((_c = (_b = viewerState.rotation) === null || _b === void 0 ? void 0 : _b.find((rotation) => rotation.pageNum === props.page.Index)) === null || _c === void 0 ? void 0 : _c.degree) || 0);
    const imageRotationRads = ((imageRotation % 180) * Math.PI) / 180;
    const boundingBox = services_1.ImageUtil.getRotatedBoundingBoxSize({
        width: (page.image && page.image.Width) || 0,
        height: (page.image && page.image.Height) || 0,
    }, imageRotation);
    const diffHeight = Math.sin(imageRotationRads) * ((props.page.Height - props.page.Width) / 2);
    const imageTransform = `translateY(${diffHeight}px) rotate(${imageRotation}deg)`;
    const handleMarkerPlacement = react_1.useCallback((event) => {
        const xCoord = event.nativeEvent.offsetX / (props.page.Height / ((page.image && page.image.Height) || 1));
        const yCoord = event.nativeEvent.offsetY / (props.page.Width / ((page.image && page.image.Width) || 1));
        if (!viewerState.isPlacingCommentMarker || xCoord <= shapes_1.MARKER_SIZE || yCoord <= shapes_1.MARKER_SIZE) {
            return;
        }
        const newCommentMarker = {
            x: `${xCoord - shapes_1.MARKER_SIZE}`,
            y: `${yCoord - shapes_1.MARKER_SIZE}`,
            id: 'draft',
            page: viewerState.activePage,
        };
        commentState.setDraft(newCommentMarker);
    }, [
        commentState,
        page.image,
        props.page.Height,
        props.page.Width,
        viewerState.activePage,
        viewerState.isPlacingCommentMarker,
    ]);
    return (react_1.default.createElement(Paper_1.default, { elevation: isActive ? 8 : 2, className: document_viewer_layout_1.PAGE_NAME, style: { margin: document_viewer_layout_1.PAGE_PADDING } },
        react_1.default.createElement("div", { style: {
                padding: 0,
                overflow: 'hidden',
                width: props.page.Width,
                height: props.page.Height,
                position: 'relative',
            }, onClick: (ev) => {
                viewerState.isPlacingCommentMarker ? handleMarkerPlacement(ev) : props.onClick(ev);
            } },
            page.image && (react_1.default.createElement("div", null,
                react_1.default.createElement(shapes_1.ShapesWidget, { zoomRatioStanding: props.page.Height / page.image.Height, zoomRatioLying: props.page.Width / page.image.Height, page: props.page }))),
            react_1.default.createElement("span", { style: { display: 'flex', justifyContent: 'center' } }, imgUrl ? (react_1.default.createElement("img", { src: `${imgUrl}${viewerState.showWatermark ? '?watermark=true' : ''}`, alt: "", style: {
                    transition: 'transform .1s ease-in-out',
                    width: `${100 * boundingBox.zoomRatio}%`,
                    height: `${100 * boundingBox.zoomRatio}%`,
                    transform: imageTransform,
                } })) : (react_1.default.createElement(CircularProgress_1.default, { style: { marginTop: '50%' } }))))));
};
exports.Page = Page;
//# sourceMappingURL=page.js.map